@@ -1,6 +1,7 @@
-from pyhandling.annotations import dirty
 from pyhandling.binders import *
 from pyhandling.branchers import *
+from pyhandling.language import *
+from pyhandling.shortcuts import *
 from pyhandling.synonyms import *
 from pyhandling.tools import *
 from pyhandling.utils import *
\ No newline at end of file
