@@ -1,4 +1,6 @@
-from typing import Container, Iterable, Self, Generator
+from typing import Container, Any, Tuple, Self, Generator
+
+from pyannotating import many_or_one
 
 
 class NonInclusiveCollection:
@@ -10,7 +12,7 @@ class NonInclusiveCollection:
     def __repr__(self) -> str:
         return f"{self.__class__.__name__}(all except {self.elements_not_contained})"
 
-    def __contains__(self, item: any) -> bool:
+    def __contains__(self, item: Any) -> bool:
         return not item in self.elements_not_contained
 
 
@@ -24,7 +26,7 @@ class MultiRange:
     desired resource.
     """
 
-    def __init__(self, range_resource: Iterable[range] | range):
+    def __init__(self, range_resource: many_or_one[range]):
         self._ranges = (
             (range_resource, )
             if isinstance(range_resource, range)
@@ -32,10 +34,10 @@ class MultiRange:
         )
 
     @property
-    def ranges(self) -> tuple[range]:
+    def ranges(self) -> Tuple[range]:
         return self._ranges
 
-    def get_with(self, range_resource: Self | Iterable[range] | range) -> Self:
+    def get_with(self, range_resource: Self | many_or_one[range]) -> Self:
         """Method that implements getting a new Multirange with additional ranges."""
 
         if isinstance(range_resource, MultiRange):
@@ -49,18 +51,18 @@ class MultiRange:
     def __repr__(self) -> str:
         return "MultiRange({})".format(', '.join(map(str, self.ranges)))
 
-    def __iter__(self) -> iter:
+    def __iter__(self) -> Generator[int, None, None]:
         return (
             item
             for range_ in self.ranges
             for item in range_
         )
 
-    def __contains__(self, item: any) -> bool:
+    def __contains__(self, item: Any) -> bool:
         return any(
             item in range_
             for range_ in self.ranges
         )
 
-    def __or__(self, range_resource: Self | Iterable[range] | range) -> Self:
+    def __or__(self, range_resource: Self | many_or_one[range]) -> Self:
         return self.get_with(range_resource)
